@@ -455,7 +455,7 @@ connect_now_home_plugin_init(ConnectNowHomePlugin *desktop_plugin)
   desktop_plugin->widget_size = CONNECTNOW_DEFAULT_WIDGET_WIDTH;
   desktop_plugin->hide_connection_name = TRUE;
   g_signal_connect(desktop_plugin->con, "connection-event", G_CALLBACK(connect_now_connection_changed), desktop_plugin);
-  g_object_set(desktop_plugin->con, "automatic-connection-events", TRUE);
+  g_object_set(desktop_plugin->con, "automatic-connection-events", TRUE, NULL);
 
   GtkWidget *contents = build_ui();
 
