@@ -38,9 +38,16 @@ typedef struct _ConnectNowHomePluginClass ConnectNowHomePluginClass;
 #define CONNECT_NOW_HOME_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), \
 								 CONNECT_NOW_HOME_PLUGIN_TYPE, ConnectNowHomePlugin))
 
+#define CONNECT_NOW_HOME_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), \
+                        CONNECT_NOW_HOME_PLUGIN_TYPE,  ConnectNowHomePluginClass))
+
 #define CONNECT_NOW_IS_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
 								CONNECT_NOW_HOME_PLUGIN_TYPE))
 
+#define CONNECT_NOW_IS_HOME_PLUGIN_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
+									   CONNECT_NOW_HOME_PLUGIN_TYPE))
+
+
 #define CONNECT_NOW_HOME_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), \
 									   CONNECT_NOW_HOME_PLUGIN_TYPE, ConnectNowHomePluginClass))
 
@@ -72,4 +79,6 @@ struct _ConnectNowHomePluginClass
 
 GType connect_now_home_plugin_get_type(void);
 
+G_END_DECLS
+
 #endif
